Apns class

Constructors

Apns({Map<String, String>? headers, ApnsPayload? payload, FcmOptions? fcmOptions})
Apns.fromJson(Map<String, dynamic> json)
factory

Properties

fcmOptions FcmOptions?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
payload ApnsPayload?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited