ApsAlert class

Constructors

ApsAlert({String? title, String? body, String? titleLocKey, List<String>? titleLocArgs, String? subtitle, String? subtitleLocKey, List<String>? subtitleLocArgs, String? bodyLocKey, List<String>? bodyLocArgs, String? launchImage})
ApsAlert.fromJson(Map<String, dynamic> json)
factory

Properties

body String?
final
bodyLocArgs List<String>?
final
bodyLocKey String?
final
hashCode int
The hash code for this object.
no setterinherited
launchImage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
subtitleLocArgs List<String>?
final
subtitleLocKey String?
final
title String?
final
titleLocArgs List<String>?
final
titleLocKey String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited