ColorRGB class

Constructors

ColorRGB({required double red, required double green, required double blue, double? alpha})
ColorRGB.fromJson(Map<String, dynamic> json)
factory

Properties

alpha → double?
final
blue → double
final
green → double
final
hashCode → int
The hash code for this object.
no setterinherited
red → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited