FcmMessage class

Constructors

FcmMessage({FcmNotification? notification, FcmData? data, FcmAndroid? android, Apns? apns, String? token, Webpush? webpush, String? topic, String? condition})
FcmMessage.fromJson(Map<String, dynamic> json)
factory

Properties

android FcmAndroid?
final
apns Apns?
final
condition String?
final
data FcmData?
final
hashCode int
The hash code for this object.
no setterinherited
notification FcmNotification?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
final
topic String?
final
webpush Webpush?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited