FcmNotification class

Constructors

FcmNotification({String? title, String? body, String? image})
FcmNotification.fromJson(Map<String, dynamic> json)
factory

Properties

body → String?
final
hashCode → int
The hash code for this object.
no setterinherited
image → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited