FirebaseService class

Singleton class for Firebase authentication

Constructors

FirebaseService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
queues Map<String, Queue>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceAccounts Map<String, Map<String, dynamic>>
serviceAccounts Give a secret key and value for FCM SECRET Json example: {'uuid':<String,dynamic>{...},}
final
serviceCallbackUrls Map<String, Map<String, String>>
final

Methods

initialize(String serviceId) Future<void>
Loads service account credentials
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendNotification(String serviceId, FcmMessage message) Future<Response>
Sends a notification to a device token
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited