Webpush class

Constructors

Webpush({Map<String, String>? headers, Map<String, String>? data, Map<String, dynamic>? notification, FcmOptions? fcmOptions})
Webpush.fromJson(Map<String, dynamic> json)
factory

Properties

data ↔ Map<String, String>?
getter/setter pair
fcmOptions ↔ FcmOptions?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>?
getter/setter pair
notification ↔ Map<String, dynamic>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited