Aps class

Constructors

Aps({String? alert, ApsAlert? alertDetails, int? badge, String? sound, String? category, String? threadId, bool? contentAvailable, bool? mutableContent, Map<String, dynamic>? customData})
Aps.fromJson(Map<String, dynamic> json)
factory

Properties

alert String?
final
alertDetails ApsAlert?
final
badge int?
final
category String?
final
contentAvailable bool?
final
customData Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
mutableContent bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sound String?
final
threadId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited