FcmAndroid class
A class for sending Firebase Cloud Messaging (FCM) messages to Android devices.
Constructors
-
FcmAndroid({String? collapseKey, String? priority, String? ttl, String? restrictedPackageName, Map<
String, String> ? data, FcmAndroidNotification? notification, FcmOptions? fcmOptions}) -
FcmAndroid.fromJson(Map<
String, dynamic> json) -
factory
Properties
- collapseKey → String?
-
final
-
data
→ Map<
String, String> ? -
final
- fcmOptions → FcmOptions?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- notification → FcmAndroidNotification?
-
final
- priority → String?
-
final
- restrictedPackageName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ttl → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited