FcmAndroidNotification class
A notification for Android devices.
Constructors
-
FcmAndroidNotification({String? title, String? body, String? icon, String? color, String? sound, String? tag, String? clickAction, String? bodyLocKey, List<
String> ? bodyLocArgs, String? titleLocKey, List<String> ? titleLocArgs, String? channelId, String? ticker, bool? sticky, DateTime? eventTime, bool? localOnly, bool? defaultSound, bool? defaultVibrateTimings, bool? defaultLightSettings, List<String> ? vibrateTimings, String? visibility, String? notificationPriority, String? image, LightSettings? lightSettings}) -
FcmAndroidNotification.fromJson(Map<
String, dynamic> json) -
factory
Properties
- body → String?
-
final
-
bodyLocArgs
→ List<
String> ? -
final
- bodyLocKey → String?
-
final
- channelId → String?
-
final
- clickAction → String?
-
final
- color → String?
-
final
- defaultLightSettings → bool?
-
final
- defaultSound → bool?
-
final
- defaultVibrateTimings → bool?
-
final
- eventTime → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
final
- image → String?
-
final
- lightSettings → LightSettings?
-
final
- localOnly → bool?
-
final
- notificationPriority → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sound → String?
-
final
- sticky → bool?
-
final
- tag → String?
-
final
- ticker → String?
-
final
- title → String?
-
final
-
titleLocArgs
→ List<
String> ? -
final
- titleLocKey → String?
-
final
-
vibrateTimings
→ List<
String> ? -
final
- visibility → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited